# ShortPaw CLI

## Installation

The Above is a simple application to use [ShortPaw]("https://shortpaw.herokuapp.com") from your commandline. Install With

```bash
pip install shortpaw
````

## Usage

The Usage is very Simple

```bash
shortpaw [OPTIONS]
-u : "URL"
-c : "Optional CUSTOM URL"
-i : "Interactive Mode"
```

# Check out [ShortPaw]("https://shortpaw.herokuapp.com")

> By NoobScience 2022